==> haskell-monadrandom-0.5.1.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MonadRandom
version: 0.5.1.1
id: MonadRandom-0.5.1.1-DQZminqWRJtFQYBJnWg1tf
key: MonadRandom-0.5.1.1-DQZminqWRJtFQYBJnWg1tf
license: BSD-3-Clause
maintainer: Brent Yorgey <byorgey@gmail.com>
author: Cale Gibbard and others
synopsis: Random-number generation monad.
description:
    Support for computations which consume random values.
category: Control
abi: 5373dcce31dda02a3cc009ea879eda81
exposed: True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict
import-dirs: /usr/lib/ghc-8.6.4/site-local/MonadRandom-0.5.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/MonadRandom-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/MonadRandom-0.5.1.1
hs-libraries: HSMonadRandom-0.5.1.1-DQZminqWRJtFQYBJnWg1tf
depends:
    base-4.12.0.0 mtl-2.2.2 primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
haddock-interfaces: /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html: /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadrandom-0.5.1.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MonadRandom
version: 0.5.1.1
id: MonadRandom-0.5.1.1-rNav53TA8P7prYsxjssg
key: MonadRandom-0.5.1.1-rNav53TA8P7prYsxjssg
license: BSD-3-Clause
maintainer: Brent Yorgey <byorgey@gmail.com>
author: Cale Gibbard and others
synopsis: Random-number generation monad.
description:
    Support for computations which consume random values.
category: Control
abi: f09820f728c4ba09ef26068de6f68f42
exposed: True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict
import-dirs: /usr/lib/ghc-8.6.4/site-local/MonadRandom-0.5.1.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/MonadRandom-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/MonadRandom-0.5.1.1
hs-libraries: HSMonadRandom-0.5.1.1-rNav53TA8P7prYsxjssg
depends:
    base-4.12.0.0 mtl-2.2.2 primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q transformers-0.5.6.2
    transformers-compat-0.6.3-1NtilqZTjCV2jyq6SVF8I5
haddock-interfaces: /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html: /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
